concretize

Function concretize 

pub fn concretize<T>(x: T) -> T
Given a symbolic value, choose an arbitrary instance that satisfies the current path condition. This function operates recursively: a call to concretize(&(x, y)) (where x and y are symbolic integers) will produce a concrete result like &(1, 2).

This function is highly magical, and should only be used if you understand its override implementation (concretize in Mir/Overrides.hs). It’s mainly intended for use in printing counterexamples, where the current execution path is terminated shortly after the concretize() call. It’s probably unwise to use this on paths that will later be joined with others.