print_str

Function print_str 

pub fn print_str(s: &str)
Print a string during symbolic execution. The string must be concrete.

Due to the way crux-mir explores paths through the program, these prints may execute in an unusual order. For example, if cond { print_str("foo") } else { print_str("bar") } may print both foo and bar in some cases.